@@ -3,8 +3,9 @@
 # SPDX-License-Identifier: AGPL-3.0-only
 
 from . import protocol
-from .experiment import Experiment, PlateSetup
+from .experiment import Experiment
 from .machine import Machine, MachineStatus, RunStatus
+from .plate_setup import PlateSetup, Sample
 from .processors import NormRaw, NormToMaxPerWell, NormToMeanPerWell, SmoothEMWMean
 from .protocol import CustomStep, Protocol, Stage, Step
 from .scpi_commands import AccessLevel
@@ -16,6 +17,7 @@ __all__ = (
     "Experiment",
     "protocol",
     "PlateSetup",
+    "Sample",
     "Protocol",
     "Stage",
     "Step",
