@@ -55,63 +55,47 @@ UR: pint.UnitRegistry = pint.UnitRegistry(
     autoconvert_offset_to_baseunit=True, auto_reduce_dimensions=True
 )
 
-Q_ = UR.Quantity
 
 log = logging.getLogger(__name__)
 
 
-def _check_unit_or_fail(val: pint.Quantity, unit: str | pint.Unit) -> None:
-    if not val.check(unit):
-        raise pint.DimensionalityError(val.u, unit)
-
-
 def _wrap_seconds(val: int | float | str | pint.Quantity) -> pint.Quantity:
     if isinstance(val, str):
-        uv = Q_(val)
-        _check_unit_or_fail(uv, "seconds")
+        uv = UR.Quantity(val)
+        uv.check("seconds")
     elif isinstance(val, pint.Quantity):
         uv = val
-        _check_unit_or_fail(uv, "seconds")
+        uv.check("seconds")
     else:
-        uv = Q_(val, "seconds")
+        uv = UR.Quantity(val, "seconds")
     return uv
 
 
 def _wrap_degC(val: int | float | str | pint.Quantity) -> pint.Quantity:
     if isinstance(val, str):
-        uv = Q_(val)
-        _check_unit_or_fail(uv, "degC")
+        uv = UR.Quantity(val)
+        uv.check("degC")
     elif isinstance(val, pint.Quantity):
         uv = val
-        _check_unit_or_fail(uv, "degC")
+        uv.check("degC")
     else:
-        uv = Q_(val, "degC")
+        uv = UR.Quantity(val, "degC")
     return uv
 
 
 def _wrap_delta_degC(val: int | float | str | pint.Quantity) -> pint.Quantity:
     if isinstance(val, str):
-        uv = Q_(val)
-        uv = _ensure_delta_temperature(uv)
+        uv = UR.Quantity(val)
+        uv.check("delta_degC")
     elif isinstance(val, pint.Quantity):
         uv = val
-        uv = _ensure_delta_temperature(uv)
+        uv.check("delta_degC")
     else:
-        uv = Q_(val, "delta_degC")
+        uv = UR.Quantity(val, "delta_degC")
     return uv
 
 
-def _ensure_delta_temperature(val: pint.Quantity) -> pint.Quantity:
-    _check_unit_or_fail(val, "delta_degC")
-
-    # Are we multiplicative?
-    if not UR._units[str(val.u)].is_multiplicative:
-        return Q_(val.m, "delta_" + str(val.u))
-
-    return val
-
-
-_ZEROTEMPDELTA = Q_(0.0, "delta_degC")
+_ZEROTEMPDELTA = UR.Quantity(0.0, "delta_degC")
 
 
 def _wrap_delta_degC_or_zero(
@@ -139,26 +123,26 @@ def _wrapunitmaybelist_degC(
     | pint.Quantity
     | Sequence[int | float | str | pint.Quantity],
 ) -> pint.Quantity:
-    unit: pint.Unit = UR.Unit("degC")
+    unit: pint.Unit = cast(pint.Unit, UR("degC"))
 
     if isinstance(val, pint.Quantity):
         uv = val
-        _check_unit_or_fail(uv, unit)
+        uv.check(unit)
     elif isinstance(val, str):
         uv = UR(val)
-        _check_unit_or_fail(uv, unit)
+        uv.check(unit)
     elif isinstance(val, Sequence):
         m = []
         for x in val:
             if isinstance(x, pint.Quantity):
                 m.append(x.to(unit).magnitude)
             elif isinstance(x, str):
-                m.append(Q_(x).to(unit).magnitude)
+                m.append(UR.Quantity(x).to(unit).magnitude)
             else:
                 m.append(x)
-        return Q_(m, unit)
+        return UR.Quantity(m, unit)
     else:
-        uv = Q_(val, unit)
+        uv = UR.Quantity(val, unit)
     return uv
 
 
@@ -256,7 +240,7 @@ class Ramp(ProtoCommand):
 
     @classmethod
     def from_scpicommand(cls, sc: SCPICommand) -> Ramp:
-        return Ramp(Q_(sc.args, "degC"), **sc.opts)  # type: ignore
+        return Ramp(UR.Quantity(sc.args, "degC"), **sc.opts)  # type: ignore
 
 
 @dataclass
@@ -334,7 +318,7 @@ class HoldAndCollect(ProtoCommand):
     """A protocol hold (for a time) and collect (set by HACFILT) command."""
 
     time: pint.Quantity[int]
-    increment: pint.Quantity[int] = Q_(0, "seconds")
+    increment: pint.Quantity[int] = UR.Quantity(0, "seconds")
     incrementcycle: int = 1
     incrementstep: int = 1
     tiff: bool = False
@@ -362,7 +346,7 @@ class HoldAndCollect(ProtoCommand):
 
     @classmethod
     def from_scpicommand(cls, sc: SCPICommand) -> HoldAndCollect:
-        return HoldAndCollect(Q_(cast(int, sc.args[0]), "seconds"), **sc.opts)  # type: ignore
+        return HoldAndCollect(UR.Quantity(cast(int, sc.args[0]), "seconds"), **sc.opts)  # type: ignore
 
 
 @dataclass
@@ -370,7 +354,7 @@ class Hold(ProtoCommand):
     """A protocol hold (for a time) command."""
 
     time: pint.Quantity[int] | None
-    increment: pint.Quantity[int] = Q_(0, "seconds")
+    increment: pint.Quantity[int] = UR.Quantity(0, "seconds")
     incrementcycle: int = 1
     incrementstep: int = 1
     _names: ClassVar[Sequence[str]] = ("HOLD",)
@@ -392,7 +376,7 @@ class Hold(ProtoCommand):
 
     @classmethod
     def from_scpicommand(cls, sc: SCPICommand) -> Hold:
-        return Hold(Q_(cast(int, sc.args[0]), "seconds"), **sc.opts)  # type: ignore
+        return Hold(UR.Quantity(cast(int, sc.args[0]), "seconds"), **sc.opts)  # type: ignore
 
 
 class XMLable(ABC):
@@ -484,10 +468,10 @@ class CustomStep(ProtoCommand, XMLable):
         return s
 
     def duration_at_cycle(self, cycle: int) -> pint.Quantity[int]:  # cycle from 1
-        return Q_(0, "second")
+        return UR.Quantity(0, "second")
 
     def temperatures_at_cycle(self, cycle: int) -> pint.Quantity[np.ndarray]:
-        return Q_(np.array(6 * [math.nan]), "degC")
+        return UR.Quantity(np.array(6 * [math.nan]), "degC")
 
     def total_duration(self, repeat: int = 1) -> pint.Quantity[int]:
         return 0 * UR.seconds
@@ -613,7 +597,7 @@ class Step(CustomStep, XMLable):
     temp_incrementcycle: int = 2
     temp_incrementpoint: int = 2
     time_increment: pint.Quantity[int] = attr.field(
-        default=Q_(0, UR.second),
+        default=UR.Quantity(0, UR.second),
         converter=_wrap_seconds,
         on_setattr=attr.setters.convert,
     )
@@ -685,9 +669,9 @@ class Step(CustomStep, XMLable):
             t = "{:.2f~}".format(temperatures)  # type: ignore
             tempstr += f" to {t}"
 
-        elems = [f"{tempstr} for {self.time:~}/cycle"]
+        elems = [f"{tempstr} for {self.time}/cycle"]
         if self.temp_increment != 0.0:
-            elems.append(f"{self.temp_increment:~}/cycle")
+            elems.append(f"{self.temp_increment}°C/cycle")
             if self.temp_incrementcycle > 1:
                 elems[-1] += f" from cycle {self.temp_incrementcycle}"
         if self.time_increment != 0.0:
@@ -748,9 +732,9 @@ class Step(CustomStep, XMLable):
     def temperature_list(self) -> pint.Quantity[np.ndarray]:
         mag = self.temperature.to("degC").magnitude  # FIXME
         if isinstance(mag, np.ndarray):
-            return Q_(mag, "degC")
+            return UR.Quantity(mag, "degC")
         else:
-            return Q_(NZONES * [mag], "degC")
+            return UR.Quantity(NZONES * [mag], "degC")
 
     @property
     def body(self) -> list[ProtoCommand]:
@@ -798,7 +782,7 @@ class Step(CustomStep, XMLable):
         cls, e: ET.Element, *, etc: int = 1, ehtc: int = 1, he: bool = False
     ) -> Step:
         collect = bool(int(e.findtext("CollectionFlag") or 0))
-        ts: pint.Quantity[np.ndarray] = Q_(
+        ts: pint.Quantity[np.ndarray] = UR.Quantity(
             [float(x.text or math.nan) for x in e.findall("Temperature")], "degC"
         )
         ht: pint.Quantity[int] = int(e.findtext("HoldTime") or 0) * UR.seconds
@@ -952,7 +936,7 @@ class Stage(XMLable, ProtoCommand):
     @classmethod
     def stepped_ramp(
         cls: Type[Stage],
-        from_temperature: float | str | pint.Quantity[float] | Sequence[float] | None,
+        from_temperature: float | str | pint.Quantity[float] | Sequence[float],
         to_temperature: float | str | pint.Quantity[float] | Sequence[float],
         total_time: int | str | pint.Quantity[int],
         *,
@@ -960,15 +944,13 @@ class Stage(XMLable, ProtoCommand):
         temperature_step: float | str | pint.Quantity[float] | None = None,
         collect: bool | None = None,
         filters: Sequence[str | FilterSet] = tuple(),
-        start_increment: bool = False,
     ) -> Stage:
         """Hold at a series of temperatures, from one to another.
 
         Parameters
         ----------
         from_temperature
-            Initial temperature/s (inclusive).  If None, uses the final temperature of
-            the previous stage.
+            Initial temperature/s (inclusive).
         to_temperature
             Final temperature/s (inclusive).
         total_time
@@ -976,12 +958,7 @@ class Stage(XMLable, ProtoCommand):
         n_steps
             Number of steps.  If None, uses 1.0 Δ°C steps, or, if
             doing a multi-temperature change, uses maximum step
-            of 1.0 Δ°C.  If n_steps is specified, it is the number of
-            temperature *steps* to take.  Normally, since there is
-            an initial cycle of the starting temperatures, this means
-            there will be `n_steps + 1` cycles.  If start_increment is True,
-            and the initial cycle is already stepped away from the starting
-            temperature, then there will be only `n_steps` cycles.
+            of 1.0 Δ°C.
         temperature_step
             Step temperature change (optional).  Must be None,
             or correctly match calculation, if n_steps is not
@@ -995,13 +972,6 @@ class Stage(XMLable, ProtoCommand):
             Collect data?  If None, collects data if filters is set explicitly.
         filters
             Filters to collect.
-        start_increment
-            If False (default), start at the `from_temperature`, holding there
-            for the same hold time as every other temperature.  If True, start
-            one step away from the `from_temperature`.  This is useful, for
-            example, if the previous stage held at a particular temperature,
-            and you now want to step *away* from that temperature.  When True,
-            note the remarks about n_steps above.
 
         Returns
         -------
@@ -1016,8 +986,12 @@ class Stage(XMLable, ProtoCommand):
 
         multistep = False
 
-        if hasattr(delta, "shape") and len(delta.shape) > 0:
-            max_delta = delta.max()  # type: pint.Quantity[float]
+        if hasattr(delta, "shape"):
+            if (delta != delta[0]).any():
+                multistep = True
+                max_delta = delta.max()  # type: pint.Quantity[float]
+            else:
+                max_delta = delta[0]
         else:
             max_delta = delta
 
@@ -1025,21 +999,13 @@ class Stage(XMLable, ProtoCommand):
 
         if n_steps is None:
             if temperature_step is None:
-                temperature_step = Q_(1.0, "delta_degC")
-                autoset_step = True
+                temperature_step = UR("1.0 delta_degC")
             else:
                 temperature_step = abs(_wrap_delta_degC(temperature_step))
-                autoset_step = False
 
-            n_steps = max(
-                abs(round((max_delta / temperature_step).to("").magnitude))
-                + (0 if start_increment else 1),
-                1,
-            )
+            n_steps = abs(round((max_delta / temperature_step).to("").magnitude)) + 1
 
-            real_max_temperature_step = abs(
-                max_delta / (n_steps - (0 if start_increment else 1))
-            )
+            real_max_temperature_step = abs(max_delta / (n_steps - 1))
 
             change = (
                 ((real_max_temperature_step - temperature_step) / temperature_step)
@@ -1047,7 +1013,7 @@ class Stage(XMLable, ProtoCommand):
                 .magnitude
             )
 
-            if (abs(change) > 0.05) and not autoset_step:
+            if abs(change) > 0.05:
                 warnings.warn(
                     f"Desired temperature step {temperature_step} differs by {100*change}% from actual {real_max_temperature_step}."
                 )
@@ -1055,27 +1021,14 @@ class Stage(XMLable, ProtoCommand):
         elif temperature_step is not None:
             temperature_step = abs(_wrap_delta_degC(temperature_step))
             if (
-                abs(round((max_delta / temperature_step).to("").magnitude))
-                + (0 if start_increment else 1)
+                abs(round((max_delta / temperature_step).to("").magnitude)) + 1
                 != n_steps
             ):
                 raise ValueError(
                     "Both n_steps and temperature_step set, and calculated steps don't match set steps."
                 )
 
-        temp_increment = (
-            (to_temperature - from_temperature)
-            / (n_steps - (0 if start_increment else 1))
-        ).round(4)
-
-        # If the temp_increment is entirely equal, we are not multistep, and we should
-        # have only a single temp_increment.
-
-        if hasattr(temp_increment, "shape") and len(temp_increment.shape) > 0:
-            if (temp_increment != temp_increment[0]).any():
-                multistep = True
-            else:
-                temp_increment = temp_increment[0]
+        temp_increment = ((to_temperature - from_temperature) / (n_steps - 1)).round(4)
 
         step_time = (total_time / n_steps).round()
 
@@ -1088,7 +1041,6 @@ class Stage(XMLable, ProtoCommand):
                         collect=collect,
                         temp_increment=temp_increment,
                         filters=filters,
-                        temp_incrementcycle=(1 if start_increment else 2),
                     )
                 ],
                 repeat=n_steps,
@@ -1100,8 +1052,7 @@ class Stage(XMLable, ProtoCommand):
             [
                 Step(
                     step_time,
-                    from_temperature
-                    + (step_i + (1 if start_increment else 0)) * temp_increment,
+                    from_temperature + step_i * temp_increment,
                     collect=collect,
                     filters=filters,
                 )
@@ -1385,7 +1336,7 @@ class Stage(XMLable, ProtoCommand):
         try:
             tot_dur = sum(
                 (x.total_duration(self.repeat) for x in self.steps),
-                Q_(0, UR.seconds),
+                UR.Quantity(0, UR.seconds),
             )
             stagestr += f" (total duration {_durformat(tot_dur)})"
         except KeyError:
